% Mulab analysis toolbox
% Version 1.05 - August 2009
%
%  COMMANDS
%
%   MULAB        - Initializes (preferences from MULAB.mat or defaults)
%                  including facility, data format, filenames ...
%                  and invokes
%   MUFIT_GUI     - The main GUI interface, generating 
%                        Figure 1: muLab FIT MENU
%                  For a description and tutorial see the webpages
%                  If you want to access data see also MU_GLOBALS
% ----------------------------------------------------------------
%   Precompiled functions: as standard in MATLAB X.m is the help,
%      whereas the compiled functions are contained in system
%      dependent files: X.mexa64 (lin 64bit) X.mexglx (lin 32bit)
%      X.mexw32 (win >R14) X.dll (win R14) 
%   FMINUIT       - Binding to MINUIT
%   ISISLOAD      - Loads old MCS ISIS data format
%   NXSLOAD       - Loads new NeXus ISIS data format
%   PSILOAD       - Loads old (ASCII) and new (BIN) PSI data format
% ----------------------------------------------------------------
%  Functions required by GUIs, in alphabetical order 
%  (to check which ones calls muwhich: grep muwhich *.m)
%  A symbol *,? follows those that can be called directly 
%  from the command window. ? indicates that HELP function is suggested
%  CONTENTS ?     - This one, try HELP CONTENTS
%  MUADD          - Adds data from another set to the loaded one(s)
%  MUADDNEWCOMPONENT  ? - Instructions, try HELP MUADDNEWCOMPONENT
%  MUASYMMETRY    - Generates TIME, ASYMMETRY and ASYMERROR 
%                   in global structure MU_DATA
%  MUCANLOAD      - Checks that run NRUN corresponds to an existing
%                   data file 
%  MUCD *         - Sets PATH for data and log files 
%  MUCOMP ?       - Returns name and indices of a parameter, try HELP MUCOMP
%  MUCOUNTPAR *   - Returns total number of parameters in model
%  MUCREATEMODEL  - Creates an empty model from the codename
%                   (e.g. 'damu'). Invoked by MUFIT_GUI
%  MUEDGE         - Estimates t0 at ISIS, try HELP MUEDGE for more
%                   info. Invoked by MUSET (hence by MUFIT_GUI)
%  MUEDITMODEL *  - To add, remove or replace components in a model
%                   handles both command and GUI versions
%  MUEXTRACTFLAG  - Parses the second input (~!=+) in the Fit Parameters 
%                   listed by MUFIT_GUI
%  MUFCN          - The core of the MINUIT fit
%                   model-assembly. Should be transparent 
%  MUFFTRES       - Perfomrs Fast Fourier Transform of fit residues
%                   Invoked by MUFIT_GUI
%  MUFIT          - Initializes, executes, and logs the FMINUIT fit
%                   internally saving into global structure
%                   MU_MODEL_F
%  MUGETCOMPONENT - Parses model codename (e.g. 'damu'), returning
%                    the indices of its components, according to the
%                    global structure MU_COMPONENT 
%  MU_GLOBALS     - Information, try HELP MU_GLOBALS
%  MUGROUP        - Translates group input strings into arrays of 
%                   detectors 
%  MUGROUPTAG     - Creates group tag for the log file name
%  MUGUESST0      - Generates a rough guess for t0 when proper
%                   value is not stored in structure MU_GEAR.NT0 
%  MUGUI2MINUIT   - Parameter index: 
%                   input is index in GUI Fit Parameters list 
%                   output is index in fminuit parameter list
%  MU_INITIALIZE_MODELS - Defines the available fit components
%                          in global structure MU_COMPONENT
%                          and the constants global structure
%                          MU_TABLE
%  MULABSAVE      - Saves setup in MULAB.mat for a quick, instument
%                   specific strartup
%  MULDMODEL *    - Loads model with file selection GUI. One can
%                   navigate to other directories to load an old
%                   model. Data and log path will not follow this
%                   selection.
%  MULISTCOMPONENTS * - Lists available components in command
%                        window
%  MULIST *       - Lists runs in present data path, generating a
%                   file readme in the same directory 
%  MULOAD ?       - Loads data, used by MUFIT_GUI, 
%                   see HELP MULOAD for more info
%  MUMODELLIST    - Edit lists of components (in MUEDITMODEL)
%  MUPAR          - Generates parameter names, values, flags,
%                   stepbounds from the guess values of MU_MODEL
%                   (MUPAR(1)) or from the best values of
%                   MU_MODEL_F (MUPAR(2)). Invoked by MUFIT,
%                   MUFFTRES, MUFIT_GUI, MUPLOTFIT
%  MUPARMINUIT    - Calculates number of parameters passed to
%                   fminuit and distributes each into panels, for
%                   MUPLOTPAR purposes
%  MUPARSE        - Parses the second input in the Fit Parameters
%                   list of MUFIT_GUI, trasnlating linear relations 
%                   and sharing relations (+=)
%  MUPLOTFIT      - Plots fit guess or best fit results, invoked 
%                   in MUFIT_GUI
%  MUPLOT         - Plots single detectors, invoked in MUFIT_GUI
%  MUPLOTPAR      - Plots fit parameters according to the Plot
%                   popup
%  MUPROMPT       - fminuit fcn function for PSI fitting of prompt
%                   peaks, invoked in MUSET
%  MUREBIN        - rebinning in MUPLOTFIT
%  MUSAVEMODEL    - save full model log in .fit file, invoked by
%                   MUFIT
%  MUSET          - Finds t0 according to a facility dependent
%                   strategy, by fitting either prompt peaks (PSI),
%                   or detector initial counts (ISIS). Better
%                   strategies from fitting the phase in series of 
%                   transverse field experiments. 
%  MUSGROUP       - Translates groups back from numeric arrays (as
%                   in structures MU_PLOT or MU_MODEL, under
%                   GROUPING.FORWARD  of GROUPING.BACKWARD) to a
%                   shorthand string, see HELP MUSGROUP
%  MUSUMMARY      - Produces logs of a fit: in the command window,
%                   in the human readable .log file and in the
%                   ascii matrix .dat file
%  MUTXTMENU      - produces a list of components in command window
%                   when invoked by MUEDITMODEL in command window
%                   (redundant)
%  MUUPDATEMODEL  - Transfers best fit value to guess values 
%  MUVALIDATEMODEL - To confirm that a user input model codename is
%                    a valid model codename (e.g. 'damu' and not
%                    'daum')
%  NORMCDF        - Integral of Gaussian based on erf
%  VALERROR       - Produces the string 3.2(1) from 3.244 and 0.127
% -----------------------------------------------------------------
%  Fit functions
%   MUDALPHA       da
%   MUBACKGROUND   ba
%   MUPRECESSION   mu
%   MUBESSEL       bj
%   MUSTRETCHED    st
%   MUKUBOGAUSS    kg
%   MUKUBOLORENTZ  kl
%   MUONIUMTRIPLET mt
%   
% ----------------------------------- -----------------------------
%  Functions not used by GUIs
%   MUCOMMENTS    - prints comments of last loaded data set (if
%                   present). See Total Counts dropdown in main GUI
%   MULAB.VERSION - Contains version and old changelogs
%
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.Analysis
%
% 
% STRATEGIES FOR A FIT FROM SCRATCH:
% 
% Path: set data and log path 
% Load data e.g. a TF calibration
% Determine t=0 (toolbar menu Setup)
% LdModel load an appropriate fit model or create one (type its shorthand
% e.g. damu for the TF calibration
% PlotFit to see the initial guess overlayed on your data
% Do Fit 
% after first fit Save Mulab (initial settings) 
% optionally PlotFit on short time range
% optionally Fft the residues, if you see significant deviations
% optionally Update if you want to fit next run from this bestfit
% as a guess
% Each fit result is automatically saved, with plenty of 
% run-specific fit infos, into a -mat file, e.g. damu.2134.2-1_1.fit
% To show an old fit in a new session, load the data, then load the fit
% result (muldmodel, choose e.g. damu.2134.2-1_1.fit, then plotfit
%
%
% Copyleft 1983-2008 G. Guidi, original minuit muon fit
%                    R. De Renzi, muzen (parent FORTRAN 77)
%                    G. Allodi, fminuit and data load functions
% Simplified GNU license: you can do whatever you like with this
% toolbox, on your PCs. If you want to recirculate a modified
% version, please let me know: roberto.derenzi at unipr.it subj: mulab

