function muset
% usage muset
% when starting analysis of a new run, calculates 
% MU_DATA.BACKGROUND, MU_DATA.NT0, MU_DATA.DT, MU_DATA.ET
% 
    
global MU_GEAR MU_TABLE MU_DATA MU_FIG
nt0=[];
dt=[];
et0=[];
back=[];
fsiz=14;
switch MU_GEAR.FACILITY
  case 'PSI'
    answer=inputdlg({'Left offset','Right offset','Fit offset'},['Background ' ...
                        'estimate'],1,{'10','10','7'});
    MU_GEAR.LBG=str2num(char(answer(1)));
    MU_GEAR.RBG=str2num(char(answer(2)));
    MU_GEAR.OFFSET=str2num(char(answer(3)));
    % must calculate prompts and background for each histo
    xl=0.12;yl=0.12;xw=0.4;yw=0.4;empty=[];
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Name','Determining t=0','MenuBar','figure')
    clf
    ax(1)=axes('position',[xl,yl,xw,yw]); % bot left
    ylabel('Counts')
    xlabel('bin')
    ax(2)=axes('position',[xl+xw,yl,xw,yw]); % bot right
    set(gca,'yticklabel',empty)
    xlabel('bin')
    ax(3)=axes('position',[xl,yl+yw,xw,yw]); % top left
    ylabel('Counts')
    set(gca,'xticklabel',empty)
    ax(4)=axes('position',[xl+xw,yl+yw,xw,yw]); % top right 
    set(gca,'xticklabel',empty,'yticklabel',empty)
    set(gca,'Box','On')

    
    for histo=1:min(size(MU_DATA.DATA,2),4) % RITE is always out
        h=MU_DATA.DATA(:,histo); % histogram
        gnt0=find(h==max(h)); % prompt bin guess
        first=find(h(1:end-1000), 1 )+MU_GEAR.LBG; % first bin for background 
        lastback=gnt0-MU_GEAR.RBG; % last bin for bakground guess
        last=gnt0+30; % last bin for prompt fit
        
        %  determine prompt for each histogram
        
        a(1)=2*h(gnt0); % Area guess
        a(2)=gnt0; % Center guess
        a(3)=1; % Sigma guess 
        a(4)=mean(h(first:lastback)); % BackLeft guess
        a(5)=mean(h(gnt0+7:gnt0+30)); % BackRight guess
        X=first:last; % here the time array is in units of bins (first=1)
        data=[X; h(X)'; sqrt(h(X))'];
        [a,ea,c]=fminuit('muprompt','mnplot',a,data,...
                         '-c','migr;exit');
        axes(ax(histo));
        hold(ax(histo),'all')
        x=gnt0-30:gnt0+30;
        errorbar(x,h(x)',sqrt(h(x))','ro')
        plot(x,muprompt(a,x),'g-')
        aa=axis;
        if histo==2, axis([aa(1)+1 aa(2) aa(3) aa(4)]); end
        hnt0=round(a(2)); % here a is a real-value fit of the bin
                          % index, for the bin containing t=0
                      % If the t=0 fit yields 0.5<a<1.5, this
                      % correctly produces nt0=1
        hdt=(a(2)-hnt0)*MU_DATA.RESNS; % if the fitted position is
                                       % to the RIGHT of the bin
                                       % center this yields a
                                       % POSITIVE dt (shift FORWARD)
        text(x(1),aa(4)*0.9,['Histo ' int2str(histo)])
        text((x(end)+x(1))/2+10,aa(4)*0.85,['N_{t0}=' num2str(hnt0)])
        text((x(end)+x(1))/2+10,aa(4)*0.7,['\delta t=' num2str(hdt,2)])
        set(gca,'Box','On')
        
        back=[back a(4)];
        nt0=[nt0 hnt0];
        dt=[dt hdt];
        et0=[et0 ea(2)*MU_DATA.RESNS];
    end
    coord=axis;
    text(coord(1)-60,1.05*coord(4),...
        ['{\fontsize{14} Prompts of } {\color[rgb]{0.1 0.2 0.8} ' ...
        MU_DATA.TITLE '}'],'fontweight','demi')
    back=[back 0]; % fake RITE
    nt0=[nt0 0]; % fake RITE
    dt=[dt 0]; % fake RITE
    et0=[et0 0]; % fake RITE
  case 'ISIS'
    lengthdata=size(MU_DATA.DATA,1);
    h=sum(MU_DATA.DATA(1:lengthdata,:),2); % unweighted sum of all histo 
    error=sqrt(h); % ZN_DATA are counts, Poisson statistics
                   % if eN(:,i)=sqrt(N:,i)) then 
                   % sum(N,2) is also the square of its errors
    dh=(h(2:end)-h(1:end-1));  % numerical derivative
    nt0=find(dh==max(dh));
    error(find(~error))=1; % error ones where X are zeros
    pin=[(nt0-1)*MU_DATA.RESNS h(nt0+10)*MU_TABLE.TAUMU 80]; 
    % initial paramenter for t0, integral counts
    bins=[1:lengthdata]';
    t=(bins-1)*MU_DATA.RESNS; % raw times: center of first bin is t=0
                              % prompt (t=0) is  
                              % MU_DATA.NT0*MU_DATA.RESNS ns after 
                              % bin center, hence bin center is at 
                              % time -MU_DATA.NT0*MU_DATA.RESNS ns 
                              % (MU_DATA.DT is the average value)
    X=[t h(bins) error(bins)]'; %errors are weighted like X
    [p ep c]=fminuit('muedge','mnplot',pin,X,'-c','migr;exit');
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Name','Determining t=0','MenuBAr','figure')
    clf
    hold(gca,'all')
    set(gca,'Box','On','Fontsize',fsiz)
    a=p(1)/MU_DATA.RESNS; % here ap(1) contains the raw time of the
                          % nt0 bin, conventionally (k-1)*RESNS
                          % where k is the bin index starting from 1
    nt0=round(a+0.5); % this is the bin containing t=0
                      % If t=0 coincided with a=zero+, t0 would be
                      % on the first bin, hence one must
                      % obtain nt0=1 
    dt=p(1)-(nt0-1)*MU_DATA.RESNS; % so dt is a shift FORWARD form
                                   % the nt0 bin center
    foreafter=30;
    if nt0-1<foreafter
        foreafter=nt0-1;
    end
    x=nt0-foreafter:nt0+foreafter;
    errorbar(x,h(x)',sqrt(h(x))','ro')
    tt=(x-1)*MU_DATA.RESNS;
    plot(x,muedge(p,tt),'g-')
    xlabel('Bins','Fontsize',fsiz)
    
    ylabel('Total counts, all detectors','Fontsize',fsiz) 
    p=axis;
    text(17,p(4)*1.02,[num2str(MU_DATA.NRUN) '  '...
                        ' ' MU_DATA.TITLE],'Fontsize',fsiz)
    text(12,p(4)*0.92,['NT0=' num2str(nt0) ', DT=' num2str(dt) ...
                   'ns'],'Fontsize',fsiz),
    N=[1 size(MU_DATA.DATA,2)];
    back=zeros(N);  % as many as the histos, all equal
    nt0=nt0*ones(N);                  % all equal
    dt=dt*ones(N);  % all equal
    et0=ep(1)*ones(N);                     % all equal
end
MU_DATA.BACKGROUND=back;
MU_DATA.NT0=nt0; 
MU_DATA.DT=dt;
MU_DATA.ET0=et0;    
MU_GEAR.NT0=nt0; % duplicate
MU_GEAR.DT=dt;   % duplicate
